INTEGER, PLUS, MINUS, EOF = 'INTEGER', 'PLUS', 'MINUS', 'EOF'


class Token:
    def __init__(self, value_type, value):
        self.value_type = value_type
        self.value = value

    def __str__(self):
        return 'Token({value_type},{value})'.format(value_type=self.value_type, value=self.value)

    def __repr__(self):  # 也可以写成 __repr__=__str__
        return self.__str__()


class Interpreter:
    def __init__(self, text):
        self.text = text
        self.position = 0
        self.current_token = None
        self.current_char = self.text[self.position]

    ##########################################################
    # 词法分析器的代码                                       #
    ##########################################################
    def error(self):
        raise Exception('警告：错误的输入内容！')

    def get_next_token(self):
        while self.current_char is not None:
            if self.current_char.isspace():
                self.skip_whitespace()
                continue
            if self.current_char.isdigit():
                return Token(INTEGER, self.long_integer())
            if self.current_char == '+':
                self.advance()
                return Token(PLUS, '+')
            if self.current_char == '-':
                self.advance()
                return Token(MINUS, '-')
            self.error()
        return Token(EOF, None)

    def advance(self):  # 获取下一个字符
        self.position += 1
        if self.position >= len(self.text):
            self.current_char = None
        else:
            self.current_char = self.text[self.position]

    def skip_whitespace(self):  # 跳过空白符
        while self.current_char is not None and self.current_char.isspace():
            self.advance()

    def long_integer(self):  # 获取多位数字
        result = ''
        while self.current_char is not None and self.current_char.isdigit():
            result += self.current_char
            self.advance()
        return int(result)

    ##########################################################
    # 语法分析器和解释器的代码                               #
    ##########################################################
    def eat(self, token_type):
        if self.current_token.value_type == token_type:
            self.current_token = self.get_next_token()
        else:
            self.error()

    def term(self):
        token = self.current_token  # 获取记号
        self.eat(INTEGER)
        return token.value  # 返回记号中的整数值

    def expr(self):
        self.current_token = self.get_next_token()
        result = self.term()  # 获取第一个整数（Term）
        while self.current_token.value_type in (PLUS, MINUS):
            if self.current_token.value_type == PLUS:
                self.eat(PLUS)
                result += self.term()  # 已有结果加上新获取的整数（Term）
            if self.current_token.value_type == MINUS:
                self.eat(MINUS)  # 已有结果减去新获取的整数（Term）
                result -= self.term()
        return result


def main():
    while True:
        try:
            text = input('>>>')
        except EOFError:
            break
        if not text:
            continue
        interpreter = Interpreter(text)
        result = interpreter.expr()
        print(text, '=', result)


if __name__ == '__main__':
    main()
